@@ -199,7 +199,7 @@ typedef int sigret_t;
 # ifdef TERMIO
 #  include <termio.h>
 # else /* SGTTY */
-#  include <sgtty.h>
+#  include <bsd/sgtty.h>
 # endif /* TERMIO */
 #else /* POSIX */
 # include <termios.h>
